#
# Copyright (C) 2016 The Android Open Source Project
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


"""Stubs for manifest class as needed."""


import error


class StubManifest(object):

    from_json_devices = {}

    def __init__(self, devices):
        """devices should be {name: (device, available)}"""
        self.devices = {name: device
                        for (name, (device, _))
                        in devices.iteritems()}
        self._available = {name: available
                           for (name, (_, available))
                           in devices.iteritems()}

    def is_bsp_available(self, device):
        if not device in self.devices:
            raise StubManifestGenerator.UnknownBspError(
                'No such device {}, options are {}'.format(
                    device, self.devices.keys()))
        return self._available[device]

    # pylint: disable=unused-argument
    @classmethod
    def from_json(cls, manifest_file=None, os_path=None):
        return cls(cls.from_json_devices)


class StubManifestGenerator(object):

    class Error(error.Error):
        pass

    class UnknownBspError(Error):
        pass

    def __init__(self):
        self.Manifest = StubManifest
