#
# Copyright (C) 2016 The Android Open Source Project
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""core.config module stubs."""


class StubConfig(object):
    """Stubs the core.config module.

    Attributes:
        user_store: the StubUserStore object that will be passed to the
            code under test. Modify this to get the desired behavior.
    """

    def __init__(self, **kwargs):
        """Initializes a StubConfig object.

        Args:
            kwargs: passed through to StubUserStore init.
        """
        self.user_store = self.StubUserStore(**kwargs)

    def UserStore(self, *_args, **_kwargs):
        """Returns our user_store object."""
        return self.user_store

    class StubUserStore(object):
        """Stubs the config.UserStore class."""

        def __init__(self, metrics_opt_in='1', is_complete=True):
            self.metrics_opt_in = metrics_opt_in
            self.is_complete = is_complete
            self.uid = 0

        def initialize(self, *_args, **_kwargs):
            pass

        def complete(self):
            return self.is_complete
